init

Function init 

pub fn init(path: &Path) -> Result<()>
Initializes a new git repository at the specified path.

Parameters

  • path: The path where the git repository should be initialized.

Returns

  • Ok(()) if the initialization was successful.
  • Err(Error) if an error occurred during initialization.