pub fn get_log(_path: &Path, _limit: Option<usize>) -> Result<Vec<GitCommit>>Expand description
Gets the git commit history (log) for the repository at the specified path.
Parameters
path: The path to the git repository.limit: Optional limit on the number of commits to return. If not provided, returns all commits.
Returns
Ok(Vec<GitCommit>)with a list of commits.Err(Error)if an error occurred while getting the commit history.